@@ -1,5 +1,8 @@
 import json
+from json import JSONDecodeError
 
+from jet_bridge_base.exceptions.request_error import RequestError
+from jet_bridge_base.exceptions.validation_error import ValidationError
 from six import string_types
 
 from jet_bridge_base import settings
@@ -52,10 +55,31 @@ class Request(object):
 
             if not isinstance(data, string_types):
                 data = data.decode('utf-8', 'surrogatepass')
-
-            self.data = json.loads(data) if data else {}
+            try:
+                self.data = json.loads(data) if data else {}
+            except ValueError as e:
+                raise RequestError(self, 'Incorrect JSON body: {}'.format(e))
         else:
-            self.data = self.body_arguments
+            def body_argument_value(value):
+                if isinstance(value, bytes):
+                    try:
+                        value = value.decode('utf-8')
+                    except:
+                        pass
+                return value
+
+            def map_item(item):
+                key, values = item
+                values = list(map(body_argument_value, values))
+                if len(values) > 1:
+                    return (key, values)
+                elif len(values) == 1:
+                    return (key, values[0])
+                else:
+                    return (key, None)
+
+            tuples = list(map(map_item, self.body_arguments.items()))
+            self.data = dict(tuples)
 
     def full_url(self):
         return self.protocol + "://" + self.host + self.uri
