@@ -33,6 +33,11 @@ DATABASE_ONLY = None
 DATABASE_EXCEPT = None
 DATABASE_SCHEMA = None
 
+DATABASE_SSH_HOST = None
+DATABASE_SSH_PORT = None
+DATABASE_SSH_USER = None
+DATABASE_SSH_PRIVATE_KEY = None
+
 COOKIE_SAMESITE = None
 COOKIE_SECURE = None
 COOKIE_DOMAIN = None
