@@ -8,16 +8,17 @@ map_data_types = [
     {'sql_type': sqltypes.VARCHAR, 'map_type': data_types.CHAR, 'db_type': data_types.CHAR},
     {'sql_type': sqltypes.CHAR, 'map_type': data_types.CHAR, 'db_type': data_types.FIXED_CHAR},
     {'sql_type': sqltypes.Unicode, 'map_type': data_types.CHAR, 'db_type': data_types.CHAR},
-    {'sql_type': sqltypes.TEXT, 'map_type': data_types.TEXT, 'db_type': data_types.TEXT},
-    {'sql_type': sqltypes.BOOLEAN, 'map_type': data_types.BOOLEAN, 'db_type': data_types.BOOLEAN},
-    {'sql_type': sqltypes.INTEGER, 'map_type': data_types.INTEGER, 'db_type': data_types.INTEGER},
-    {'sql_type': sqltypes.SMALLINT, 'map_type': data_types.INTEGER, 'db_type': data_types.SMALL_INTEGER},
-    {'sql_type': sqltypes.BIGINT, 'map_type': data_types.INTEGER, 'db_type': data_types.BIG_INTEGER},
-    {'sql_type': sqltypes.NUMERIC, 'map_type': data_types.FLOAT, 'db_type': data_types.NUMBER},
-    {'sql_type': sqltypes.FLOAT, 'map_type': data_types.FLOAT, 'db_type': data_types.FLOAT},
+    {'sql_type': sqltypes.Text, 'map_type': data_types.TEXT, 'db_type': data_types.TEXT},
+    {'sql_type': sqltypes.Enum, 'map_type': data_types.SELECT, 'db_type': data_types.SELECT},
+    {'sql_type': sqltypes.Boolean, 'map_type': data_types.BOOLEAN, 'db_type': data_types.BOOLEAN},
+    {'sql_type': sqltypes.Integer, 'map_type': data_types.INTEGER, 'db_type': data_types.INTEGER},
+    {'sql_type': sqltypes.SmallInteger, 'map_type': data_types.INTEGER, 'db_type': data_types.SMALL_INTEGER},
+    {'sql_type': sqltypes.BigInteger, 'map_type': data_types.INTEGER, 'db_type': data_types.BIG_INTEGER},
+    {'sql_type': sqltypes.Numeric, 'map_type': data_types.FLOAT, 'db_type': data_types.NUMBER},
+    {'sql_type': sqltypes.Float, 'map_type': data_types.FLOAT, 'db_type': data_types.FLOAT},
     {'sql_type': sqltypes.DECIMAL, 'map_type': data_types.FLOAT, 'db_type': data_types.DECIMAL},
-    {'sql_type': sqltypes.DATE, 'map_type': data_types.DATE, 'db_type': data_types.DATE},
-    {'sql_type': sqltypes.DATETIME, 'map_type': data_types.DATE_TIME, 'db_type': data_types.DATE_TIME},
+    {'sql_type': sqltypes.Date, 'map_type': data_types.DATE, 'db_type': data_types.DATE},
+    {'sql_type': sqltypes.DateTime, 'map_type': data_types.DATE_TIME, 'db_type': data_types.DATE_TIME},
     {'sql_type': sqltypes.TIMESTAMP, 'map_type': data_types.DATE_TIME, 'db_type': data_types.TIMESTAMP},
     {'sql_type': sqltypes.JSON, 'map_type': data_types.JSON, 'db_type': data_types.JSON},
 ]
